@@ -6,9 +6,9 @@ library(tableHTML)
 tableHTML(mtcars)
 
 ## ----rownames------------------------------------------------------------
-tableHTML(mtcars, rownames = FALSE)
+tableHTML(mtcars, rownames=FALSE)
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval=FALSE---------------------------------------------------------
 #  mytable <- tableHTML(mtcars)
 #  str(mytable)
 #  # Classes 'tableHTML', 'html', 'character'  atomic [1:1]
@@ -19,8 +19,8 @@ tableHTML(mtcars, rownames = FALSE)
 #  #   <th id="tableHTML_header_3">cyl</th>
 #  # truncated...
 
-## ---- eval = FALSE-------------------------------------------------------
-#  mytable <- tableHTML(mtcars, class = 'myClass')
+## ---- eval=FALSE---------------------------------------------------------
+#  mytable <- tableHTML(mtcars, class='myClass')
 #  str(mytable)
 #  # Classes 'tableHTML', 'html', 'character'  atomic [1:1]
 #  # <table class=myClass border=1 style="border-collapse: collapse;">
@@ -30,10 +30,10 @@ tableHTML(mtcars, rownames = FALSE)
 #  #   <th id="tableHTML_header_3">cyl</th>
 #  # truncated...
 
-## ----second header-------------------------------------------------------
+## ----secondheader--------------------------------------------------------
 tableHTML(mtcars, second_headers = list(c(3, 4, 5), c('col1', 'col2', 'col3')))
 
-## ----row groups----------------------------------------------------------
+## ----rowgroups-----------------------------------------------------------
 tableHTML(mtcars, 
           rownames = FALSE, 
           row_groups = list(c(10, 10, 12), c('Group 1', 'Group 2', 'Group 3')))
@@ -52,41 +52,37 @@ tableHTML(mtcars, caption = 'This is  a table')
 ## ----footer--------------------------------------------------------------
 tableHTML(mtcars, footer = 'This is  a footer')
 
-## ----collapse, eval = FALSE----------------------------------------------
+## ----collapse, eval=FALSE------------------------------------------------
 #  tableHTML(mtcars, collapse = 'separate')
 
-## ----collapse 2----------------------------------------------------------
+## ----collapse2-----------------------------------------------------------
 tableHTML(mtcars, collapse = 'separate_shiny')
 
-## ----spacing 1-----------------------------------------------------------
+## ----spacing1------------------------------------------------------------
 tableHTML(mtcars, collapse = 'separate_shiny', spacing = '2px')
 
-## ----spacing 2-----------------------------------------------------------
+## ----spacing2------------------------------------------------------------
 tableHTML(mtcars, collapse = 'separate_shiny', spacing = '5px 2px')
 
 ## ----escaping------------------------------------------------------------
 df <- data.frame(a = c('abcd<efgh'))
 tableHTML(df, escape = FALSE, rownames = FALSE)
+
+## ----escaping_2----------------------------------------------------------
 tableHTML(df, escape = TRUE, rownames = FALSE)
 
-## ----theme-scientific----------------------------------------------------
-tableHTML(mtcars, widths = c(140, rep(50, 11)), theme = 'scientific')
-
-## ----theme-rshiny-blue---------------------------------------------------
-tableHTML(mtcars, widths = c(140, rep(50, 11)), theme = 'rshiny-blue')
-
-## ----add css row 1-------------------------------------------------------
+## ----addcssrow1----------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11))) %>% 
   add_css_row(css = list(c('background-color', 'border'), c('lightblue', '2px solid lightgray')))
 
-## ----add css row 2-------------------------------------------------------
+## ----addcssrow2----------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11))) %>% 
   add_css_row(css = list(c('background-color', 'border'), c('lightblue', '2px solid lightgray')),
               rows = 2:33)
 
-## ----add css row 3-------------------------------------------------------
+## ----addcssrow3----------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11))) %>% 
   add_css_row(css = list('background-color', '#f2f2f2'),
@@ -100,7 +96,7 @@ mtcars %>%
   add_css_column(css = list(c('background-color', 'border'), c('lightblue', '3px solid lightgray')), 
                  columns = c('cyl', 'hp', 'rownames'))
 
-## ----add css column 2----------------------------------------------------
+## ----addcsscolumn2-------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11))) %>% 
   add_css_row(css = list('background-color', '#f2f2f2')) %>%
@@ -108,7 +104,7 @@ mtcars %>%
                  columns = c('cyl', 'hp', 'rownames')) 
  
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval=FALSE---------------------------------------------------------
 #  mytable <- tableHTML(mtcars)
 #  print(mytable, viewer = FALSE)
 #  <table style="border-collapse:collapse;" class=table_2079 border=1>
@@ -119,12 +115,12 @@ mtcars %>%
 #    <th id="tableHTML_header_3">cyl</th>
 #  truncated...
 
-## ----add css header 1----------------------------------------------------
+## ----addcssheader1-------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11))) %>% 
   add_css_header(css = list('background-color', 'lightgray'), headers = c(1, 4))
 
-## ----add css second header 1---------------------------------------------
+## ----addcsssecondheader1-------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11)), 
             second_headers = list(c(3, 4, 5), c('col1', 'col2', 'col3'))) %>% 
@@ -132,46 +128,46 @@ mtcars %>%
                                    c('lightgray', '3px solid green')),
                         second_headers = c(1, 3))  
 
-## ----add css caption-----------------------------------------------------
+## ----addcsscaption-------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11)), 
             caption = 'This is a table') %>% 
   add_css_caption(css = list(c('color', 'font-size', 'text-align'), c('blue', '20px', 'left')))  
 
-## ----add css footer------------------------------------------------------
+## ----addcssfooter--------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11)), 
             footer = 'This is a footer') %>% 
   add_css_footer(css = list(c('color', 'font-size', 'text-align'), c('blue', '20px', 'left')))  
 
-## ----add css thead-------------------------------------------------------
+## ----addcssthead---------------------------------------------------------
 mtcars %>%
   tableHTML() %>% 
   add_css_thead(css = list('background-color', 'lightgray')) 
 
-## ----add css tbody-------------------------------------------------------
+## ----addcsstbody---------------------------------------------------------
 mtcars %>%
   tableHTML() %>% 
   add_css_tbody(css = list('background-color', 'lightgray')) 
 
-## ----thead example 1-----------------------------------------------------
+## ----theadexample1-------------------------------------------------------
 mtcars %>%
   tableHTML() %>% 
   add_css_thead(css = list('background-color', 'lightgray')) %>%
   add_css_row(css = list('background-color', 'blue'), rows = 1)
 
-## ----thead example 2-----------------------------------------------------
+## ----theadexample2-------------------------------------------------------
 mtcars %>%
   tableHTML() %>% 
   add_css_tbody(css = list('background-color', 'lightgray')) %>%
   add_css_row(css = list('background-color', 'blue'), rows = c(4, 6))
 
-## ----add css table-------------------------------------------------------
+## ----addcsstable---------------------------------------------------------
 mtcars %>%
   tableHTML() %>% 
   add_css_table(css = list('background-color', 'lightgray')) 
 
-## ----all together--------------------------------------------------------
+## ----alltogether---------------------------------------------------------
 mtcars %>%
   tableHTML(widths = c(140, rep(45, 11)),
             second_headers = list(c(3, 4, 5), c('team1', 'team2', 'team3')),
@@ -191,13 +187,18 @@ mtcars %>%
   add_css_caption(css = list(c('text-align', 'font-size', 'color'), c('center', '20px', 'black'))) %>%
   add_css_footer(css = list(c('text-align', 'color'), c('left', 'black')))
 
-## ----replace html--------------------------------------------------------
+## ----replacehtml---------------------------------------------------------
 mtcars %>%
  tableHTML(widths = c(140, rep(45, 11))) %>%
  replace_html(' <td id="tableHTML_column_1">21</td>', 
               '<td id="mpg" style="background-color:lightyellow">21</td>')
 
-## ----shiny 1, eval = FALSE-----------------------------------------------
+## ----picture, eval=FALSE-------------------------------------------------
+#  mtcars %>%
+#    tableHTML() %>%
+#    tableHTML_to_image()
+
+## ----shiny1, eval=FALSE--------------------------------------------------
 #  library(shiny)
 #  shinyApp(
 #   ui = fluidPage(
@@ -213,7 +214,7 @@ mtcars %>%
 #   )}
 #  )
 
-## ----shiny 2, eval = FALSE-----------------------------------------------
+## ----shiny2, eval=FALSE--------------------------------------------------
 #  shinyApp(
 #   ui = fluidPage(
 #     fluidRow(
@@ -242,7 +243,7 @@ mtcars %>%
 #   )}
 #  )
 
-## ----shiny css, eval = FALSE---------------------------------------------
+## ----shinycss, eval=FALSE------------------------------------------------
 #  #ui.R
 #  shinyUI(
 #   fluidPage(
@@ -264,3 +265,21 @@ mtcars %>%
 #     )}
 #  )
 
+## ----css_ex1, echo=FALSE-------------------------------------------------
+mtcars %>%
+  tableHTML(second_headers = list(c(3, 4, 5), c('col1', 'col2', 'col3'))) %>%
+  add_css_column(list('border-left', '5px solid red'), columns = 1)
+
+## ----css_ex2, echo=FALSE-------------------------------------------------
+mtcars %>%
+  tableHTML(second_headers = list(c(3, 4, 5), c('col1', 'col2', 'col3'))) %>%
+  add_css_column(list('border-left', '5px solid red'), columns = 1) %>%
+  add_css_header(list('background-color', 'green'), 2)
+
+## ----css_ex3, echo=FALSE-------------------------------------------------
+mtcars %>%
+  tableHTML(second_headers = list(c(3, 4, 5), c('col1', 'col2', 'col3'))) %>%
+  add_css_column(list('border-left', '5px solid red'), columns = 1) %>%
+  add_css_header(list('background-color', 'green'), 2) %>%
+  add_css_second_header(list('background-color', 'steelblue'), 1)
+
